@@ -12,6 +12,7 @@ used.
 
 import collections
 import json
+import pickle
 
 from rasterio._crs import _CRS, all_proj_keys
 from rasterio.compat import string_types
@@ -66,23 +67,7 @@ class CRS(collections.Mapping):
             data = dict(initialdata or {})
             data.update(**kwargs)
             data = {k: v for k, v in data.items() if k in all_proj_keys}
-
-            # always use lowercase 'epsg'.
-            if 'init' in data:
-                data['init'] = data['init'].replace('EPSG:', 'epsg:')
-
-            proj_parts = []
-
-            for key, val in data.items():
-                if val is False or None:
-                    continue
-                elif val is True:
-                    proj_parts.append('+{}'.format(key))
-                else:
-                    proj_parts.append('+{}={}'.format(key, val))
-
-            proj = ' '.join(proj_parts)
-            self._crs = _CRS.from_proj4(proj)
+            self._crs = _CRS.from_dict(data)
 
         else:
             self._crs = _CRS()
@@ -105,6 +90,20 @@ class CRS(collections.Mapping):
         other = CRS.from_user_input(other)
         return (self._crs == other._crs)
 
+    def __getstate__(self):
+        return self.to_wkt()
+
+    def __setstate__(self, state):
+        self._wkt = None
+        self._data = None
+        self._crs = _CRS.from_wkt(state)
+
+    def __copy__(self):
+        return pickle.loads(pickle.dumps(self))
+
+    def __hash__(self):
+        return hash(self.to_wkt())
+
     def to_proj4(self):
         """Convert CRS to a PROJ4 string
 
@@ -239,6 +238,19 @@ class CRS(collections.Mapping):
         except CRSError:
             return False
 
+    @property
+    def linear_units(self):
+        """The linear units of the CRS
+
+        Possible values include "metre" and "US survey foot".
+
+        Returns
+        -------
+        str
+
+        """
+        return self._crs.linear_units
+
     def to_string(self):
         """Convert CRS to a PROJ4 or WKT string
 
@@ -266,7 +278,7 @@ class CRS(collections.Mapping):
     def __repr__(self):
         epsg_code = self.to_epsg()
         if epsg_code:
-            return "CRS.from_dict(init='epsg:{}')".format(epsg_code)
+            return "CRS.from_epsg({})".format(epsg_code)
         else:
             return "CRS.from_wkt('{}')".format(self.wkt)
 
